You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@lucene.apache.org by rm...@apache.org on 2014/06/17 19:03:57 UTC

svn commit: r1603221 - in /lucene/dev/branches/branch_4x: ./ lucene/ lucene/analysis/icu/src/java/ lucene/benchmark/src/test/org/apache/lucene/benchmark/byTask/tasks/ lucene/core/ lucene/core/src/java/org/apache/lucene/store/ lucene/core/src/java/org/a...

Author: rmuir
Date: Tue Jun 17 17:03:55 2014
New Revision: 1603221

URL: http://svn.apache.org/r1603221
Log:
add 4.10

Modified:
    lucene/dev/branches/branch_4x/   (props changed)
    lucene/dev/branches/branch_4x/build.xml
    lucene/dev/branches/branch_4x/lucene/   (props changed)
    lucene/dev/branches/branch_4x/lucene/CHANGES.txt   (contents, props changed)
    lucene/dev/branches/branch_4x/lucene/analysis/icu/src/java/overview.html
    lucene/dev/branches/branch_4x/lucene/benchmark/src/test/org/apache/lucene/benchmark/byTask/tasks/CreateIndexTaskTest.java
    lucene/dev/branches/branch_4x/lucene/common-build.xml
    lucene/dev/branches/branch_4x/lucene/core/   (props changed)
    lucene/dev/branches/branch_4x/lucene/core/src/java/org/apache/lucene/store/NRTCachingDirectory.java
    lucene/dev/branches/branch_4x/lucene/core/src/java/org/apache/lucene/util/Constants.java
    lucene/dev/branches/branch_4x/lucene/core/src/java/org/apache/lucene/util/Version.java
    lucene/dev/branches/branch_4x/lucene/demo/src/java/org/apache/lucene/demo/IndexFiles.java
    lucene/dev/branches/branch_4x/lucene/demo/src/java/org/apache/lucene/demo/SearchFiles.java
    lucene/dev/branches/branch_4x/lucene/demo/src/java/org/apache/lucene/demo/facet/FacetExamples.java
    lucene/dev/branches/branch_4x/lucene/facet/src/java/org/apache/lucene/facet/taxonomy/directory/DirectoryTaxonomyWriter.java
    lucene/dev/branches/branch_4x/lucene/test-framework/src/java/org/apache/lucene/util/LuceneTestCase.java
    lucene/dev/branches/branch_4x/solr/   (props changed)
    lucene/dev/branches/branch_4x/solr/CHANGES.txt   (contents, props changed)
    lucene/dev/branches/branch_4x/solr/example/example-DIH/solr/db/conf/solrconfig.xml
    lucene/dev/branches/branch_4x/solr/example/example-DIH/solr/mail/conf/solrconfig.xml
    lucene/dev/branches/branch_4x/solr/example/example-DIH/solr/rss/conf/solrconfig.xml
    lucene/dev/branches/branch_4x/solr/example/example-DIH/solr/solr/conf/solrconfig.xml
    lucene/dev/branches/branch_4x/solr/example/example-DIH/solr/tika/conf/solrconfig.xml
    lucene/dev/branches/branch_4x/solr/example/example-schemaless/solr/collection1/conf/solrconfig.xml
    lucene/dev/branches/branch_4x/solr/example/multicore/core0/conf/solrconfig.xml
    lucene/dev/branches/branch_4x/solr/example/multicore/core1/conf/solrconfig.xml
    lucene/dev/branches/branch_4x/solr/example/solr/collection1/conf/solrconfig.xml

Modified: lucene/dev/branches/branch_4x/build.xml
URL: http://svn.apache.org/viewvc/lucene/dev/branches/branch_4x/build.xml?rev=1603221&r1=1603220&r2=1603221&view=diff
==============================================================================
--- lucene/dev/branches/branch_4x/build.xml (original)
+++ lucene/dev/branches/branch_4x/build.xml Tue Jun 17 17:03:55 2014
@@ -136,7 +136,7 @@
     </subant>
   </target>
 
-  <property name="version" value="4.9-SNAPSHOT"/>
+  <property name="version" value="4.10-SNAPSHOT"/>
   <property name="maven-build-dir" value="maven-build"/>
   <property name="maven-version" value="2.2.1"/>
 
@@ -351,7 +351,7 @@ File | Project Structure | Platform Sett
   <property name="python32.exe" value="python3.2" />
   <property name="fakeRelease" location="lucene/build/fakeRelease"/>
   <property name="fakeReleaseTmp" location="lucene/build/fakeReleaseTmp"/>
-  <property name="fakeReleaseVersion" value="4.9.0"/> <!-- *not* -SNAPSHOT, the real version -->
+  <property name="fakeReleaseVersion" value="4.10.0"/> <!-- *not* -SNAPSHOT, the real version -->
   <property name="smokeTestRelease.testArgs" value=""/>
 
   <target name="-load-env">

Modified: lucene/dev/branches/branch_4x/lucene/CHANGES.txt
URL: http://svn.apache.org/viewvc/lucene/dev/branches/branch_4x/lucene/CHANGES.txt?rev=1603221&r1=1603220&r2=1603221&view=diff
==============================================================================
--- lucene/dev/branches/branch_4x/lucene/CHANGES.txt (original)
+++ lucene/dev/branches/branch_4x/lucene/CHANGES.txt Tue Jun 17 17:03:55 2014
@@ -3,6 +3,10 @@ Lucene Change Log
 For more information on past and future Lucene versions, please see:
 http://s.apache.org/luceneversions
 
+======================= Lucene 4.10.0 ======================
+
+(No Changes)
+
 ======================= Lucene 4.9.0 =======================
 
 Changes in Runtime Behavior

Modified: lucene/dev/branches/branch_4x/lucene/analysis/icu/src/java/overview.html
URL: http://svn.apache.org/viewvc/lucene/dev/branches/branch_4x/lucene/analysis/icu/src/java/overview.html?rev=1603221&r1=1603220&r2=1603221&view=diff
==============================================================================
--- lucene/dev/branches/branch_4x/lucene/analysis/icu/src/java/overview.html (original)
+++ lucene/dev/branches/branch_4x/lucene/analysis/icu/src/java/overview.html Tue Jun 17 17:03:55 2014
@@ -115,9 +115,9 @@ algorithm.
 <h3>Farsi Range Queries</h3>
 <pre class="prettyprint">
   Collator collator = Collator.getInstance(new ULocale("ar"));
-  ICUCollationKeyAnalyzer analyzer = new ICUCollationKeyAnalyzer(Version.LUCENE_4_9, collator);
+  ICUCollationKeyAnalyzer analyzer = new ICUCollationKeyAnalyzer(Version.LUCENE_4_10, collator);
   RAMDirectory ramDir = new RAMDirectory();
-  IndexWriter writer = new IndexWriter(ramDir, new IndexWriterConfig(Version.LUCENE_4_9, analyzer));
+  IndexWriter writer = new IndexWriter(ramDir, new IndexWriterConfig(Version.LUCENE_4_10, analyzer));
   Document doc = new Document();
   doc.add(new Field("content", "\u0633\u0627\u0628", 
                     Field.Store.YES, Field.Index.ANALYZED));
@@ -125,7 +125,7 @@ algorithm.
   writer.close();
   IndexSearcher is = new IndexSearcher(ramDir, true);
 
-  QueryParser aqp = new QueryParser(Version.LUCENE_4_9, "content", analyzer);
+  QueryParser aqp = new QueryParser(Version.LUCENE_4_10, "content", analyzer);
   aqp.setAnalyzeRangeTerms(true);
     
   // Unicode order would include U+0633 in [ U+062F - U+0698 ], but Farsi
@@ -141,9 +141,9 @@ algorithm.
 <h3>Danish Sorting</h3>
 <pre class="prettyprint">
   Analyzer analyzer 
-    = new ICUCollationKeyAnalyzer(Version.LUCENE_4_9, Collator.getInstance(new ULocale("da", "dk")));
+    = new ICUCollationKeyAnalyzer(Version.LUCENE_4_10, Collator.getInstance(new ULocale("da", "dk")));
   RAMDirectory indexStore = new RAMDirectory();
-  IndexWriter writer = new IndexWriter(indexStore, new IndexWriterConfig(Version.LUCENE_4_9, analyzer));
+  IndexWriter writer = new IndexWriter(indexStore, new IndexWriterConfig(Version.LUCENE_4_10, analyzer));
   String[] tracer = new String[] { "A", "B", "C", "D", "E" };
   String[] data = new String[] { "HAT", "HUT", "H\u00C5T", "H\u00D8T", "HOT" };
   String[] sortedTracerOrder = new String[] { "A", "E", "B", "D", "C" };
@@ -169,15 +169,15 @@ algorithm.
 <pre class="prettyprint">
   Collator collator = Collator.getInstance(new ULocale("tr", "TR"));
   collator.setStrength(Collator.PRIMARY);
-  Analyzer analyzer = new ICUCollationKeyAnalyzer(Version.LUCENE_4_9, collator);
+  Analyzer analyzer = new ICUCollationKeyAnalyzer(Version.LUCENE_4_10, collator);
   RAMDirectory ramDir = new RAMDirectory();
-  IndexWriter writer = new IndexWriter(ramDir, new IndexWriterConfig(Version.LUCENE_4_9, analyzer));
+  IndexWriter writer = new IndexWriter(ramDir, new IndexWriterConfig(Version.LUCENE_4_10, analyzer));
   Document doc = new Document();
   doc.add(new Field("contents", "DIGY", Field.Store.NO, Field.Index.ANALYZED));
   writer.addDocument(doc);
   writer.close();
   IndexSearcher is = new IndexSearcher(ramDir, true);
-  QueryParser parser = new QueryParser(Version.LUCENE_4_9, "contents", analyzer);
+  QueryParser parser = new QueryParser(Version.LUCENE_4_10, "contents", analyzer);
   Query query = parser.parse("d\u0131gy");   // U+0131: dotless i
   ScoreDoc[] result = is.search(query, null, 1000).scoreDocs;
   assertEquals("The index Term should be included.", 1, result.length);

Modified: lucene/dev/branches/branch_4x/lucene/benchmark/src/test/org/apache/lucene/benchmark/byTask/tasks/CreateIndexTaskTest.java
URL: http://svn.apache.org/viewvc/lucene/dev/branches/branch_4x/lucene/benchmark/src/test/org/apache/lucene/benchmark/byTask/tasks/CreateIndexTaskTest.java?rev=1603221&r1=1603220&r2=1603221&view=diff
==============================================================================
--- lucene/dev/branches/branch_4x/lucene/benchmark/src/test/org/apache/lucene/benchmark/byTask/tasks/CreateIndexTaskTest.java (original)
+++ lucene/dev/branches/branch_4x/lucene/benchmark/src/test/org/apache/lucene/benchmark/byTask/tasks/CreateIndexTaskTest.java Tue Jun 17 17:03:55 2014
@@ -38,7 +38,7 @@ public class CreateIndexTaskTest extends
   private PerfRunData createPerfRunData(String infoStreamValue) throws Exception {
     Properties props = new Properties();
     // :Post-Release-Update-Version.LUCENE_XY:
-    props.setProperty("writer.version", Version.LUCENE_4_9.toString());
+    props.setProperty("writer.version", Version.LUCENE_4_10.toString());
     props.setProperty("print.props", "false"); // don't print anything
     props.setProperty("directory", "RAMDirectory");
     if (infoStreamValue != null) {

Modified: lucene/dev/branches/branch_4x/lucene/common-build.xml
URL: http://svn.apache.org/viewvc/lucene/dev/branches/branch_4x/lucene/common-build.xml?rev=1603221&r1=1603220&r2=1603221&view=diff
==============================================================================
--- lucene/dev/branches/branch_4x/lucene/common-build.xml (original)
+++ lucene/dev/branches/branch_4x/lucene/common-build.xml Tue Jun 17 17:03:55 2014
@@ -50,8 +50,8 @@
   <property name="Name" value="Lucene"/>
   
   <property name="name" value="${ant.project.name}"/>
-  <property name="tests.luceneMatchVersion" value="4.9"/>
-  <property name="dev.version.base" value="4.9"/>
+  <property name="tests.luceneMatchVersion" value="4.10"/>
+  <property name="dev.version.base" value="4.10"/>
   <property name="dev.version.suffix" value="SNAPSHOT"/>
   <property name="dev.version" value="${dev.version.base}-${dev.version.suffix}"/>
   <property name="version" value="${dev.version}"/>

Modified: lucene/dev/branches/branch_4x/lucene/core/src/java/org/apache/lucene/store/NRTCachingDirectory.java
URL: http://svn.apache.org/viewvc/lucene/dev/branches/branch_4x/lucene/core/src/java/org/apache/lucene/store/NRTCachingDirectory.java?rev=1603221&r1=1603220&r2=1603221&view=diff
==============================================================================
--- lucene/dev/branches/branch_4x/lucene/core/src/java/org/apache/lucene/store/NRTCachingDirectory.java (original)
+++ lucene/dev/branches/branch_4x/lucene/core/src/java/org/apache/lucene/store/NRTCachingDirectory.java Tue Jun 17 17:03:55 2014
@@ -51,7 +51,7 @@ import org.apache.lucene.util.IOUtils;
  * <pre class="prettyprint">
  *   Directory fsDir = FSDirectory.open(new File("/path/to/index"));
  *   NRTCachingDirectory cachedFSDir = new NRTCachingDirectory(fsDir, 5.0, 60.0);
- *   IndexWriterConfig conf = new IndexWriterConfig(Version.LUCENE_4_9, analyzer);
+ *   IndexWriterConfig conf = new IndexWriterConfig(Version.LUCENE_4_10, analyzer);
  *   IndexWriter writer = new IndexWriter(cachedFSDir, conf);
  * </pre>
  *

Modified: lucene/dev/branches/branch_4x/lucene/core/src/java/org/apache/lucene/util/Constants.java
URL: http://svn.apache.org/viewvc/lucene/dev/branches/branch_4x/lucene/core/src/java/org/apache/lucene/util/Constants.java?rev=1603221&r1=1603220&r2=1603221&view=diff
==============================================================================
--- lucene/dev/branches/branch_4x/lucene/core/src/java/org/apache/lucene/util/Constants.java (original)
+++ lucene/dev/branches/branch_4x/lucene/core/src/java/org/apache/lucene/util/Constants.java Tue Jun 17 17:03:55 2014
@@ -118,7 +118,7 @@ public final class Constants {
    * anything else is not allowed. This is done to prevent people from
    * using indexes created with ALPHA/BETA versions with the released version.
    */
-  public static final String LUCENE_MAIN_VERSION = ident("4.9");
+  public static final String LUCENE_MAIN_VERSION = ident("4.10");
 
   /**
    * This is the Lucene version for display purposes.

Modified: lucene/dev/branches/branch_4x/lucene/core/src/java/org/apache/lucene/util/Version.java
URL: http://svn.apache.org/viewvc/lucene/dev/branches/branch_4x/lucene/core/src/java/org/apache/lucene/util/Version.java?rev=1603221&r1=1603220&r2=1603221&view=diff
==============================================================================
--- lucene/dev/branches/branch_4x/lucene/demo/src/java/org/apache/lucene/demo/IndexFiles.java (original)
+++ lucene/dev/branches/branch_4x/lucene/demo/src/java/org/apache/lucene/demo/IndexFiles.java Tue Jun 17 17:03:55 2014
@@ -88,8 +88,8 @@ public class IndexFiles {
 
       Directory dir = FSDirectory.open(new File(indexPath));
       // :Post-Release-Update-Version.LUCENE_XY:
-      Analyzer analyzer = new StandardAnalyzer(Version.LUCENE_4_9);
-      IndexWriterConfig iwc = new IndexWriterConfig(Version.LUCENE_4_9, analyzer);
+      Analyzer analyzer = new StandardAnalyzer(Version.LUCENE_4_10);
+      IndexWriterConfig iwc = new IndexWriterConfig(Version.LUCENE_4_10, analyzer);
 
       if (create) {
         // Create a new index in the directory, removing any

Modified: lucene/dev/branches/branch_4x/lucene/demo/src/java/org/apache/lucene/demo/SearchFiles.java
URL: http://svn.apache.org/viewvc/lucene/dev/branches/branch_4x/lucene/demo/src/java/org/apache/lucene/demo/SearchFiles.java?rev=1603221&r1=1603220&r2=1603221&view=diff
==============================================================================
--- lucene/dev/branches/branch_4x/lucene/demo/src/java/org/apache/lucene/demo/SearchFiles.java (original)
+++ lucene/dev/branches/branch_4x/lucene/demo/src/java/org/apache/lucene/demo/SearchFiles.java Tue Jun 17 17:03:55 2014
@@ -91,7 +91,7 @@ public class SearchFiles {
     IndexReader reader = DirectoryReader.open(FSDirectory.open(new File(index)));
     IndexSearcher searcher = new IndexSearcher(reader);
     // :Post-Release-Update-Version.LUCENE_XY:
-    Analyzer analyzer = new StandardAnalyzer(Version.LUCENE_4_9);
+    Analyzer analyzer = new StandardAnalyzer(Version.LUCENE_4_10);
 
     BufferedReader in = null;
     if (queries != null) {
@@ -100,7 +100,7 @@ public class SearchFiles {
       in = new BufferedReader(new InputStreamReader(System.in, StandardCharsets.UTF_8));
     }
     // :Post-Release-Update-Version.LUCENE_XY:
-    QueryParser parser = new QueryParser(Version.LUCENE_4_9, field, analyzer);
+    QueryParser parser = new QueryParser(Version.LUCENE_4_10, field, analyzer);
     while (true) {
       if (queries == null && queryString == null) {                        // prompt the user
         System.out.println("Enter query: ");

Modified: lucene/dev/branches/branch_4x/lucene/demo/src/java/org/apache/lucene/demo/facet/FacetExamples.java
URL: http://svn.apache.org/viewvc/lucene/dev/branches/branch_4x/lucene/demo/src/java/org/apache/lucene/demo/facet/FacetExamples.java?rev=1603221&r1=1603220&r2=1603221&view=diff
==============================================================================
--- lucene/dev/branches/branch_4x/lucene/demo/src/java/org/apache/lucene/demo/facet/FacetExamples.java (original)
+++ lucene/dev/branches/branch_4x/lucene/demo/src/java/org/apache/lucene/demo/facet/FacetExamples.java Tue Jun 17 17:03:55 2014
@@ -28,6 +28,6 @@ public interface FacetExamples {
 
   // :Post-Release-Update-Version.LUCENE_XY:
   /** The Lucene {@link Version} used by the example code. */
-  public static final Version EXAMPLES_VER = Version.LUCENE_4_9;
+  public static final Version EXAMPLES_VER = Version.LUCENE_4_10;
 
 }

Modified: lucene/dev/branches/branch_4x/lucene/facet/src/java/org/apache/lucene/facet/taxonomy/directory/DirectoryTaxonomyWriter.java
URL: http://svn.apache.org/viewvc/lucene/dev/branches/branch_4x/lucene/facet/src/java/org/apache/lucene/facet/taxonomy/directory/DirectoryTaxonomyWriter.java?rev=1603221&r1=1603220&r2=1603221&view=diff
==============================================================================
--- lucene/dev/branches/branch_4x/lucene/facet/src/java/org/apache/lucene/facet/taxonomy/directory/DirectoryTaxonomyWriter.java (original)
+++ lucene/dev/branches/branch_4x/lucene/facet/src/java/org/apache/lucene/facet/taxonomy/directory/DirectoryTaxonomyWriter.java Tue Jun 17 17:03:55 2014
@@ -286,7 +286,7 @@ public class DirectoryTaxonomyWriter imp
     // :Post-Release-Update-Version.LUCENE_XY:
     // Make sure we use a MergePolicy which always merges adjacent segments and thus
     // keeps the doc IDs ordered as well (this is crucial for the taxonomy index).
-    return new IndexWriterConfig(Version.LUCENE_4_9,
+    return new IndexWriterConfig(Version.LUCENE_4_10,
         null).setOpenMode(openMode).setMergePolicy(
         new LogByteSizeMergePolicy());
   }

Modified: lucene/dev/branches/branch_4x/lucene/test-framework/src/java/org/apache/lucene/util/LuceneTestCase.java
URL: http://svn.apache.org/viewvc/lucene/dev/branches/branch_4x/lucene/test-framework/src/java/org/apache/lucene/util/LuceneTestCase.java?rev=1603221&r1=1603220&r2=1603221&view=diff
==============================================================================
--- lucene/dev/branches/branch_4x/lucene/test-framework/src/java/org/apache/lucene/util/LuceneTestCase.java (original)
+++ lucene/dev/branches/branch_4x/lucene/test-framework/src/java/org/apache/lucene/util/LuceneTestCase.java Tue Jun 17 17:03:55 2014
@@ -375,7 +375,7 @@ public abstract class LuceneTestCase ext
    * Use this constant when creating Analyzers and any other version-dependent stuff.
    * <p><b>NOTE:</b> Change this when development starts for new Lucene version:
    */
-  public static final Version TEST_VERSION_CURRENT = Version.LUCENE_4_9;
+  public static final Version TEST_VERSION_CURRENT = Version.LUCENE_4_10;
 
   /**
    * True if and only if tests are run in verbose mode. If this flag is false

Modified: lucene/dev/branches/branch_4x/solr/CHANGES.txt
URL: http://svn.apache.org/viewvc/lucene/dev/branches/branch_4x/solr/CHANGES.txt?rev=1603221&r1=1603220&r2=1603221&view=diff
==============================================================================
--- lucene/dev/branches/branch_4x/solr/CHANGES.txt (original)
+++ lucene/dev/branches/branch_4x/solr/CHANGES.txt Tue Jun 17 17:03:55 2014
@@ -23,6 +23,10 @@ $Id$
 * SOLR-5868: HttpClient should be configured to use ALLOW_ALL_HOSTNAME hostname
   verifier to simplify SSL setup. (Steve Davids via Mark Miller)
 
+==================  4.10.0 =================
+
+(No Changes)
+
 ==================  4.9.0 ==================
 
 Versions of Major Components

Modified: lucene/dev/branches/branch_4x/solr/example/example-DIH/solr/db/conf/solrconfig.xml
URL: http://svn.apache.org/viewvc/lucene/dev/branches/branch_4x/solr/example/example-DIH/solr/db/conf/solrconfig.xml?rev=1603221&r1=1603220&r2=1603221&view=diff
==============================================================================
--- lucene/dev/branches/branch_4x/solr/example/example-DIH/solr/db/conf/solrconfig.xml (original)
+++ lucene/dev/branches/branch_4x/solr/example/example-DIH/solr/db/conf/solrconfig.xml Tue Jun 17 17:03:55 2014
@@ -35,7 +35,7 @@
        that you fully re-index after changing this setting as it can
        affect both how text is indexed and queried.
   -->
-  <luceneMatchVersion>4.9</luceneMatchVersion>
+  <luceneMatchVersion>4.10</luceneMatchVersion>
 
   <!-- <lib/> directives can be used to instruct Solr to load an Jars
        identified and use them to resolve any "plugins" specified in

Modified: lucene/dev/branches/branch_4x/solr/example/example-DIH/solr/mail/conf/solrconfig.xml
URL: http://svn.apache.org/viewvc/lucene/dev/branches/branch_4x/solr/example/example-DIH/solr/mail/conf/solrconfig.xml?rev=1603221&r1=1603220&r2=1603221&view=diff
==============================================================================
--- lucene/dev/branches/branch_4x/solr/example/example-DIH/solr/mail/conf/solrconfig.xml (original)
+++ lucene/dev/branches/branch_4x/solr/example/example-DIH/solr/mail/conf/solrconfig.xml Tue Jun 17 17:03:55 2014
@@ -35,7 +35,7 @@
        that you fully re-index after changing this setting as it can
        affect both how text is indexed and queried.
   -->
-  <luceneMatchVersion>4.9</luceneMatchVersion>
+  <luceneMatchVersion>4.10</luceneMatchVersion>
 
   <!-- <lib/> directives can be used to instruct Solr to load an Jars
        identified and use them to resolve any "plugins" specified in

Modified: lucene/dev/branches/branch_4x/solr/example/example-DIH/solr/rss/conf/solrconfig.xml
URL: http://svn.apache.org/viewvc/lucene/dev/branches/branch_4x/solr/example/example-DIH/solr/rss/conf/solrconfig.xml?rev=1603221&r1=1603220&r2=1603221&view=diff
==============================================================================
--- lucene/dev/branches/branch_4x/solr/example/example-DIH/solr/rss/conf/solrconfig.xml (original)
+++ lucene/dev/branches/branch_4x/solr/example/example-DIH/solr/rss/conf/solrconfig.xml Tue Jun 17 17:03:55 2014
@@ -35,7 +35,7 @@
        that you fully re-index after changing this setting as it can
        affect both how text is indexed and queried.
   -->
-  <luceneMatchVersion>4.9</luceneMatchVersion>
+  <luceneMatchVersion>4.10</luceneMatchVersion>
 
   <!-- <lib/> directives can be used to instruct Solr to load an Jars
        identified and use them to resolve any "plugins" specified in

Modified: lucene/dev/branches/branch_4x/solr/example/example-DIH/solr/solr/conf/solrconfig.xml
URL: http://svn.apache.org/viewvc/lucene/dev/branches/branch_4x/solr/example/example-DIH/solr/solr/conf/solrconfig.xml?rev=1603221&r1=1603220&r2=1603221&view=diff
==============================================================================
--- lucene/dev/branches/branch_4x/solr/example/example-DIH/solr/solr/conf/solrconfig.xml (original)
+++ lucene/dev/branches/branch_4x/solr/example/example-DIH/solr/solr/conf/solrconfig.xml Tue Jun 17 17:03:55 2014
@@ -35,7 +35,7 @@
        that you fully re-index after changing this setting as it can
        affect both how text is indexed and queried.
   -->
-  <luceneMatchVersion>4.9</luceneMatchVersion>
+  <luceneMatchVersion>4.10</luceneMatchVersion>
 
   <!-- <lib/> directives can be used to instruct Solr to load an Jars
        identified and use them to resolve any "plugins" specified in

Modified: lucene/dev/branches/branch_4x/solr/example/example-DIH/solr/tika/conf/solrconfig.xml
URL: http://svn.apache.org/viewvc/lucene/dev/branches/branch_4x/solr/example/example-DIH/solr/tika/conf/solrconfig.xml?rev=1603221&r1=1603220&r2=1603221&view=diff
==============================================================================
--- lucene/dev/branches/branch_4x/solr/example/example-DIH/solr/tika/conf/solrconfig.xml (original)
+++ lucene/dev/branches/branch_4x/solr/example/example-DIH/solr/tika/conf/solrconfig.xml Tue Jun 17 17:03:55 2014
@@ -35,7 +35,7 @@
        that you fully re-index after changing this setting as it can
        affect both how text is indexed and queried.
   -->
-  <luceneMatchVersion>4.9</luceneMatchVersion>
+  <luceneMatchVersion>4.10</luceneMatchVersion>
 
   <!-- <lib/> directives can be used to instruct Solr to load an Jars
        identified and use them to resolve any "plugins" specified in

Modified: lucene/dev/branches/branch_4x/solr/example/example-schemaless/solr/collection1/conf/solrconfig.xml
URL: http://svn.apache.org/viewvc/lucene/dev/branches/branch_4x/solr/example/example-schemaless/solr/collection1/conf/solrconfig.xml?rev=1603221&r1=1603220&r2=1603221&view=diff
==============================================================================
--- lucene/dev/branches/branch_4x/solr/example/example-schemaless/solr/collection1/conf/solrconfig.xml (original)
+++ lucene/dev/branches/branch_4x/solr/example/example-schemaless/solr/collection1/conf/solrconfig.xml Tue Jun 17 17:03:55 2014
@@ -35,7 +35,7 @@
        that you fully re-index after changing this setting as it can
        affect both how text is indexed and queried.
   -->
-  <luceneMatchVersion>4.9</luceneMatchVersion>
+  <luceneMatchVersion>4.10</luceneMatchVersion>
 
   <!-- <lib/> directives can be used to instruct Solr to load an Jars
        identified and use them to resolve any "plugins" specified in

Modified: lucene/dev/branches/branch_4x/solr/example/multicore/core0/conf/solrconfig.xml
URL: http://svn.apache.org/viewvc/lucene/dev/branches/branch_4x/solr/example/multicore/core0/conf/solrconfig.xml?rev=1603221&r1=1603220&r2=1603221&view=diff
==============================================================================
--- lucene/dev/branches/branch_4x/solr/example/multicore/core0/conf/solrconfig.xml (original)
+++ lucene/dev/branches/branch_4x/solr/example/multicore/core0/conf/solrconfig.xml Tue Jun 17 17:03:55 2014
@@ -21,7 +21,7 @@
  It is *not* a good example to work from. 
 -->
 <config>
-  <luceneMatchVersion>4.9</luceneMatchVersion>
+  <luceneMatchVersion>4.10</luceneMatchVersion>
   <!--  The DirectoryFactory to use for indexes.
         solr.StandardDirectoryFactory, the default, is filesystem based.
         solr.RAMDirectoryFactory is memory based, not persistent, and doesn't work with replication. -->

Modified: lucene/dev/branches/branch_4x/solr/example/multicore/core1/conf/solrconfig.xml
URL: http://svn.apache.org/viewvc/lucene/dev/branches/branch_4x/solr/example/multicore/core1/conf/solrconfig.xml?rev=1603221&r1=1603220&r2=1603221&view=diff
==============================================================================
--- lucene/dev/branches/branch_4x/solr/example/multicore/core1/conf/solrconfig.xml (original)
+++ lucene/dev/branches/branch_4x/solr/example/multicore/core1/conf/solrconfig.xml Tue Jun 17 17:03:55 2014
@@ -21,7 +21,7 @@
  It is *not* a good example to work from. 
 -->
 <config>
-  <luceneMatchVersion>4.9</luceneMatchVersion>
+  <luceneMatchVersion>4.10</luceneMatchVersion>
   <!--  The DirectoryFactory to use for indexes.
         solr.StandardDirectoryFactory, the default, is filesystem based.
         solr.RAMDirectoryFactory is memory based, not persistent, and doesn't work with replication. -->

Modified: lucene/dev/branches/branch_4x/solr/example/solr/collection1/conf/solrconfig.xml
URL: http://svn.apache.org/viewvc/lucene/dev/branches/branch_4x/solr/example/solr/collection1/conf/solrconfig.xml?rev=1603221&r1=1603220&r2=1603221&view=diff
==============================================================================
--- lucene/dev/branches/branch_4x/solr/example/solr/collection1/conf/solrconfig.xml (original)
+++ lucene/dev/branches/branch_4x/solr/example/solr/collection1/conf/solrconfig.xml Tue Jun 17 17:03:55 2014
@@ -35,7 +35,7 @@
        that you fully re-index after changing this setting as it can
        affect both how text is indexed and queried.
   -->
-  <luceneMatchVersion>4.9</luceneMatchVersion>
+  <luceneMatchVersion>4.10</luceneMatchVersion>
 
   <!-- <lib/> directives can be used to instruct Solr to load an Jars
        identified and use them to resolve any "plugins" specified in
--- lucene/dev/branches/branch_4x/lucene/core/src/java/org/apache/lucene/util/Version.java (original)
+++ lucene/dev/branches/branch_4x/lucene/core/src/java/org/apache/lucene/util/Version.java Tue Jun 17 17:03:55 2014
@@ -137,12 +137,17 @@ public enum Version {
   @Deprecated
   LUCENE_4_8,
 
   /** Match settings and bugs in Lucene's 4.9 release.
    *  <p>
    *  Use this to get the latest &amp; greatest settings, bug
    *  fixes, etc, for Lucene.
    */
+  @Deprecated
   LUCENE_4_9,
+  
+  /**
+   * Match settings and bugs in Lucene's 4.10 release.
+   */
+  LUCENE_4_10,
 
   /* Add new constants for later versions **here** to respect order! */
 
@@ -137,12 +137,17 @@ public enum Version {
   LUCENE_4_8,
 
-  /** Match settings and bugs in Lucene's 4.9 release.
-   *  <p>
-   *  Use this to get the latest &amp; greatest settings, bug
-   *  fixes, etc, for Lucene.
+  /**
+   * Match settings and bugs in Lucene's 4.9 release.
+   * @deprecated (4.10) Use latest
    */

Modified: lucene/dev/branches/branch_4x/lucene/demo/src/java/org/apache/lucene/demo/IndexFiles.java
URL: http://svn.apache.org/viewvc/lucene/dev/branches/branch_4x/lucene/demo/src/java/org/apache/lucene/demo/IndexFiles.java?rev=1603221&r1=1603220&r2=1603221&view=diff
==============================================================================